import { CommonModule } from '@angular/common';
import { Injectable, NgModule, Optional, SkipSelf } from '@angular/core';
import 'rxjs/add/operator/toPromise';
import { HttpClient, HttpHeaders } from '@angular/common/http';

class XmlUtilities {
    /**
     * @param {?} stringToEscape
     * @return {?}
     */
    static escapeString(stringToEscape) {
        if (stringToEscape)
            return (stringToEscape + "")
                .replace(/&(?!(amp;)|(lt;)|(gt;)|(quot;)|(#39;)|(apos;))/g, "&amp;")
                .replace(/</g, '&lt;')
                .replace(/>/g, '&gt;')
                .replace(/"/g, '&quot;')
                .replace(/'/g, '&apos;');
        return stringToEscape;
    }
}

//new http client 
class SharepointListsWebService {
    /**
     * @param {?} http
     */
    constructor(http$$1) {
        this.http = http$$1;
        this.serviceUrl = '_vti_bin/Lists.asmx';
        this.xmlPayloadWrapperStart = `<?xml version="1.0" encoding="utf-8"?>
<soap12:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:soap12="http://www.w3.org/2003/05/soap-envelope">
  <soap12:Body>`;
        this.xmlPayloadWrapperEnd = '</soap12:Body></soap12:Envelope>';
        this.getListItemsPayload = `
    <GetListItems xmlns="http://schemas.microsoft.com/sharepoint/soap/">
      <listName>listNamePayLoad</listName>
      <viewName>viewNamePayLoad</viewName>
      <query>queryPayload</query>
      <viewFields>viewFieldsPayload</viewFields>
      <rowLimit>rowLimitPayload</rowLimit>
      <QueryOptions>queryOptionsPayload</QueryOptions>
    </GetListItems>`;
        this.updateListItemsPayload = `<UpdateListItems xmlns="http://schemas.microsoft.com/sharepoint/soap/"><listName>listNamePayLoad</listName><updates>updatesPayLoad</updates></UpdateListItems>`;
        this.headers = new HttpHeaders().set('Content-Type', 'application/soap+xml; charset=utf-8');
    }
    /**
     * @param {?} ctor
     * @param {?} filterQuery
     * @param {?} camlQuery
     * @param {?} orderByField
     * @return {?}
     */
    getListItems(ctor, filterQuery, camlQuery, orderByField) {
        let /** @type {?} */ dummyInstance = new ctor();
        let /** @type {?} */ currentPayload = this.xmlPayloadWrapperStart + this.getListItemsPayload + this.xmlPayloadWrapperEnd;
        currentPayload = currentPayload.replace("listNamePayLoad", XmlUtilities.escapeString(dummyInstance.getListName()));
        currentPayload = currentPayload.replace("viewNamePayLoad", "");
        if (filterQuery || camlQuery) {
            if (filterQuery) {
                let /** @type {?} */ internalCamlQuery = "<Query><Where><Eq><FieldRef Name='FieldName' /><Value Type='Text'>ValueName</Value></Eq></Where></Query>";
                internalCamlQuery = internalCamlQuery.replace("FieldName", filterQuery[0]);
                internalCamlQuery = internalCamlQuery.replace("ValueName", XmlUtilities.escapeString(filterQuery[1]));
                currentPayload = currentPayload.replace("queryPayload", internalCamlQuery);
            }
            else {
                currentPayload = currentPayload.replace("queryPayload", camlQuery);
            }
        }
        else {
            currentPayload = currentPayload.replace("queryPayload", "");
        }
        currentPayload = currentPayload.replace("viewFieldsPayload", "");
        currentPayload = currentPayload.replace("rowLimitPayload", "");
        currentPayload = currentPayload.replace("queryOptionsPayload", "");
        return this.http.post(dummyInstance.getSiteUrl() + this.serviceUrl, currentPayload, { headers: this.headers, responseType: 'text' })
            .toPromise()
            .then(function (res) {
            let /** @type {?} */ filledResponse = [];
            $(res).find("z\\:row, row").each(function (index) {
                filledResponse.push(new ctor($(this)[0].attributes));
            });
            return filledResponse;
        })
            .catch(this.handleError);
    }
    /**
     * @param {?} itemToUpdate
     * @param {?} newValue
     * @return {?}
     */
    updateListItem(itemToUpdate, newValue) {
        let /** @type {?} */ currentPayload = this.xmlPayloadWrapperStart + this.updateListItemsPayload + this.xmlPayloadWrapperEnd;
        currentPayload = currentPayload.replace("listNamePayLoad", XmlUtilities.escapeString(itemToUpdate.getListName()));
        currentPayload = currentPayload.replace("updatesPayLoad", `<Batch OnError="Continue"><Method ID="1" Cmd="Update"><Field Name="ID">` + itemToUpdate.ID + `</Field><Field Name="` + itemToUpdate.getFieldToUpdate() + `">` + XmlUtilities.escapeString(newValue) + `</Field></Method></Batch>`);
        return this.http.post(itemToUpdate.getSiteUrl() + this.serviceUrl, currentPayload, { headers: this.headers, responseType: 'text' })
            .toPromise()
            .then(() => null)
            .catch(this.handleError);
    }
    /**
     * @param {?} error
     * @return {?}
     */
    handleError(error) {
        console.error('An error occurred', error); // for demo purposes only
        return Promise.reject(error.message || error);
    }
    /**
     * @param {?} itemToUpdate
     * @param {?} keyValuePairs
     * @return {?}
     */
    addOrUpdateListItem(itemToUpdate, keyValuePairs) {
        let /** @type {?} */ currentPayload = this.xmlPayloadWrapperStart + this.updateListItemsPayload + this.xmlPayloadWrapperEnd;
        let /** @type {?} */ perColumnString = `<Field Name="fieldName">fieldValue</Field>`;
        let /** @type {?} */ allColumnsToUpdate = '';
        let /** @type {?} */ command = "New";
        //if there is an existing 'ID' property with a value, then this is not new but update.
        for (let /** @type {?} */ i = 0; i < keyValuePairs.length; i++) {
            if (keyValuePairs[i][0] == "ID" && keyValuePairs[i][1]) {
                command = "Update";
                break;
            }
        }
        keyValuePairs.forEach(entry => allColumnsToUpdate = allColumnsToUpdate + perColumnString.replace("fieldName", entry[0]).replace("fieldValue", XmlUtilities.escapeString(entry[1])));
        currentPayload = currentPayload.replace("listNamePayLoad", XmlUtilities.escapeString(itemToUpdate.getListName()));
        currentPayload = currentPayload.replace("updatesPayLoad", `<Batch OnError="Continue"><Method ID="1" Cmd="` + command + `">` + allColumnsToUpdate + `</Method></Batch>`);
        return this.http.post(itemToUpdate.getSiteUrl() + this.serviceUrl, currentPayload, { headers: this.headers, responseType: 'text' })
            .toPromise()
            .then(function (res) {
            return +$(res).find("z\\:row:first, row:first").attr("ows_ID");
        })
            .catch(this.handleError);
    }
    /**
     * @param {?} itemsToRemove
     * @return {?}
     */
    removeListItems(itemsToRemove) {
        let /** @type {?} */ currentPayload = this.xmlPayloadWrapperStart + this.updateListItemsPayload + this.xmlPayloadWrapperEnd;
        currentPayload = currentPayload.replace("listNamePayLoad", XmlUtilities.escapeString(itemsToRemove[0].getListName()));
        let /** @type {?} */ updatesPayload = '<Batch OnError="Continue">';
        for (let /** @type {?} */ methodId = 1; methodId <= itemsToRemove.length; methodId++) {
            updatesPayload += '<Method ID="' + methodId + '" Cmd="Delete"><Field Name="ID">' + itemsToRemove[methodId - 1].ID + '</Field></Method>';
        }
        updatesPayload += "</Batch>";
        currentPayload = currentPayload.replace("updatesPayLoad", updatesPayload);
        return this.http.post(itemsToRemove[0].getSiteUrl() + this.serviceUrl, currentPayload, { headers: this.headers, responseType: 'text' })
            .toPromise().then(function (res) {
            let /** @type {?} */ errorList = [];
            $(res).find("result:not(:contains('0x00000000'))").each(function (index) {
                errorList.push($(this).find('ErrorCode').text());
            });
            return Promise.resolve(errorList);
        })
            .catch(this.handleError);
    }
    /**
     * @param {?} itemsToAddOrUpdate
     * @return {?}
     */
    addOrUpdateListItems(itemsToAddOrUpdate) {
        let /** @type {?} */ currentPayload = this.xmlPayloadWrapperStart + this.updateListItemsPayload + this.xmlPayloadWrapperEnd;
        currentPayload = currentPayload.replace("listNamePayLoad", XmlUtilities.escapeString(itemsToAddOrUpdate[0].getListName()));
        let /** @type {?} */ updatesPayload = '<Batch OnError="Continue">';
        let /** @type {?} */ idFieldXml;
        for (let /** @type {?} */ i = 0; i < itemsToAddOrUpdate.length; i++) {
            idFieldXml = "";
            if (itemsToAddOrUpdate[i].ID && itemsToAddOrUpdate[i].ID > 0)
                idFieldXml = '<Field Name="ID">' + itemsToAddOrUpdate[i].ID + '</Field>';
            updatesPayload += '<Method ID="' + (i + 1) + '" Cmd="' + (idFieldXml ? "Update" : "New") + '">';
            if (idFieldXml)
                updatesPayload += idFieldXml;
            for (let /** @type {?} */ property of itemsToAddOrUpdate[i].getItemProperties()) {
                if (property != "ID") {
                    updatesPayload += '<Field Name="' + property + '">' + XmlUtilities.escapeString(itemsToAddOrUpdate[i][property]) + '</Field>';
                }
            }
            updatesPayload += "</Method>";
        }
        updatesPayload += "</Batch>";
        currentPayload = currentPayload.replace("updatesPayLoad", updatesPayload);
        return this.http.post(itemsToAddOrUpdate[0].getSiteUrl() + this.serviceUrl, currentPayload, { headers: this.headers, responseType: 'text' })
            .toPromise().then((res) => {
            let /** @type {?} */ finalResult = [];
            let /** @type {?} */ counter = 0;
            let /** @type {?} */ currentItem;
            $(res).find("Result").each(function (index) {
                // first, check for errors...
                currentItem = itemsToAddOrUpdate[counter];
                if ($(this).find('ErrorCode').text() != '0x00000000') {
                    finalResult.push([currentItem, $(this).find('ErrorCode').text()]);
                }
                else {
                    if ((!currentItem.ID) || currentItem.ID == 0) {
                        currentItem.ID = +$(this).find("z\\:row, row").attr("ows_ID");
                    }
                    finalResult.push([currentItem, ""]);
                }
                counter++;
            });
            return finalResult;
        }).catch(this.handleError);
    }
}
SharepointListsWebService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
SharepointListsWebService.ctorParameters = () => [
    { type: HttpClient, },
];

/**
 * Dummy version of an authenticated user service
 */
class UrlService {
    /**
     * @return {?}
     */
    navigateToDefaultSource() {
        if (GetUrlKeyValue('Source', false, window.location.href)) {
            window.location.href = GetUrlKeyValue('Source', false, window.location.href);
        }
        else {
            window.location.href = _spPageContextInfo.webServerRelativeUrl;
        }
    }
    /**
     * @return {?}
     */
    getItemId() {
        try {
            return GetUrlKeyValue('ID', false, window.location.href);
        }
        catch (x) {
            return '';
        }
    }
    /**
     * @return {?}
     */
    getCurrentSiteUrl() {
        return _spPageContextInfo.webServerRelativeUrl + "/";
    }
}
UrlService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
UrlService.ctorParameters = () => [];

class SharePointUserProfile {
}

class SharePointUserProfileWebService {
    /**
     * @param {?} http
     */
    constructor(http$$1) {
        this.http = http$$1;
        this.serviceUrl = '/_vti_bin/UserProfileService.asmx';
        this.xmlPayloadWrapperStart = `<?xml version="1.0" encoding="utf-8"?>
<soap12:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:soap12="http://www.w3.org/2003/05/soap-envelope">
  <soap12:Body>`;
        this.xmlPayloadWrapperEnd = '</soap12:Body></soap12:Envelope>';
        this.getUserProfileByNamePayload = `
    <GetUserProfileByName xmlns="http://microsoft.com/webservices/SharePointPortalServer/UserProfileService">
      <AccountName>accountNameString</AccountName>
    </GetUserProfileByName>`;
        this.headers = new HttpHeaders().set('Content-Type', 'application/soap+xml; charset=utf-8');
    }
    /**
     * @param {?=} accountName
     * @return {?}
     */
    getUserProfileByName(accountName) {
        let /** @type {?} */ currentPayload = this.xmlPayloadWrapperStart + this.getUserProfileByNamePayload + this.xmlPayloadWrapperEnd;
        if (accountName) {
            currentPayload = currentPayload.replace("accountNameString", accountName);
        }
        else {
            currentPayload = currentPayload.replace("accountNameString", "");
        }
        return this.http.post(this.serviceUrl, currentPayload, { headers: this.headers, responseType: 'text' })
            .toPromise()
            .then(function (res) {
            let /** @type {?} */ filledResponse = new SharePointUserProfile();
            let /** @type {?} */ jQueryValue = $(res).find("PropertyData:has(name:contains('WorkEmail'))").find('value').text();
            if (jQueryValue) {
                filledResponse.workEmail = jQueryValue;
            }
            jQueryValue = $(res).find("PropertyData:has(name:contains('WorkPhone'))").find('value').text();
            if (jQueryValue) {
                filledResponse.workPhone = jQueryValue;
            }
            $(res).find("z\\:row, row").each(function (index) {
                
                //$(this)[0].attributes)
                //do some fancy jquery coding here.
            });
            return filledResponse;
        })
            .catch(this.handleError);
    }
    /**
     * @param {?} error
     * @return {?}
     */
    handleError(error) {
        console.error('An error occurred', error); // for demo purposes only
        return Promise.reject(error.message || error);
    }
}
/* return this.http.post(dummyInstance.getSiteUrl()+this.serviceUrl, currentPayload,{headers:this.headers,})
.toPromise()
.then(function(res)
    {
        let filledResponse:SharepointListItem[] = [];
        $(res.text()).find("z\\:row, row").each(function( index:any ) {
            filledResponse.push(new ctor($(this)[0].attributes));
        });
        return filledResponse;
})
.catch(this.handleError);
}



.then(function (res){
    return +$(res.text()).find("z\\:row:first, row:first").attr("ows_ID");
})
.catch(this.handleError);
} */
SharePointUserProfileWebService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
SharePointUserProfileWebService.ctorParameters = () => [
    { type: HttpClient, },
];

class SharepointUserGroupWebService {
    /**
     * @param {?} http
     */
    constructor(http$$1) {
        this.http = http$$1;
        this.serviceUrl = '_vti_bin/UserGroup.asmx';
        this.xmlPayloadWrapperStart = `<?xml version="1.0" encoding="utf-8"?>
<soap12:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:soap12="http://www.w3.org/2003/05/soap-envelope">
  <soap12:Body>`;
        this.xmlPayloadWrapperEnd = '</soap12:Body></soap12:Envelope>';
        this.headers = new HttpHeaders().set('Content-Type', 'application/soap+xml; charset=utf-8');
        this.getUserLoginFromEmailPayload = `<GetUserLoginFromEmail xmlns="http://schemas.microsoft.com/sharepoint/soap/directory/"><emailXml><Users>payload</Users></emailXml></GetUserLoginFromEmail>`;
        this.addUserCollectionToGroupPayload = `<AddUserCollectionToGroup xmlns="http://schemas.microsoft.com/sharepoint/soap/directory/">
      <groupName>groupNamePayload</groupName>
      <usersInfoXml><Users>usersPayload</Users></usersInfoXml>
    </AddUserCollectionToGroup>`;
        this.removeUserCollectionFromGroupPayload = `<RemoveUserCollectionFromGroup xmlns="http://schemas.microsoft.com/sharepoint/soap/directory/">
      <groupName>groupNamePayload</groupName>
      <userLoginNamesXml><Users>usersPayload</Users></userLoginNamesXml>
    </RemoveUserCollectionFromGroup>`;
        this.getUserCollectionFromGroupPayload = `<GetUserCollectionFromGroup xmlns="http://schemas.microsoft.com/sharepoint/soap/directory/">
      <groupName>groupNamePayload</groupName></GetUserCollectionFromGroup>`;
    }
    /**
     * @param {?} emailStrings
     * @param {?} siteurl
     * @return {?}
     */
    getUserLoginFromEmail(emailStrings, siteurl) {
        let /** @type {?} */ requestBody = this.xmlPayloadWrapperStart + this.getUserLoginFromEmailPayload + this.xmlPayloadWrapperEnd;
        let /** @type {?} */ userString = "<User Email=\"emailString\"/>";
        let /** @type {?} */ finalPayload = "";
        for (let /** @type {?} */ x = 0; x < emailStrings.length; x++) {
            finalPayload += userString.replace("emailString", emailStrings[x]);
        }
        requestBody = requestBody.replace("payload", finalPayload);
        return this.http.post(siteurl + this.serviceUrl, requestBody, { headers: this.headers, responseType: 'text' })
            .toPromise()
            .then(function (res) {
            let /** @type {?} */ result = [];
            $(res).find("User").each(function (index) {
                result.push({ id: $(this).attr('SiteUser'), displayName: $(this).attr('DisplayName'), login: $(this).attr('Login'), email: $(this).attr('Email') });
            });
            return result;
        })
            .catch(this.handleError);
    }
    /**
     * @param {?} users
     * @param {?} groupName
     * @param {?} siteurl
     * @return {?}
     */
    addUserCollectionToGroup(users, groupName, siteurl) {
        let /** @type {?} */ requestBody = this.xmlPayloadWrapperStart + this.addUserCollectionToGroupPayload + this.xmlPayloadWrapperEnd;
        requestBody = requestBody.replace("groupNamePayload", groupName);
        let /** @type {?} */ internalpayload = "";
        for (let /** @type {?} */ x = 0; x < users.length; x++) {
            /*internalpayload+="<User LoginName=\""+users[x].login+"\" Email=\""
            +users[x].email+"\" Name=\""+ users[x].displayName +"\"/>";*/
            internalpayload += "<User LoginName=\"" + users[x].login + "\"/>";
        }
        requestBody = requestBody.replace("usersPayload", internalpayload);
        return this.http.post(siteurl + this.serviceUrl, requestBody, { headers: this.headers, responseType: 'text' })
            .toPromise()
            .then(function (res) {
            return 0;
        })
            .catch(this.handleError);
    }
    /**
     * @param {?} users
     * @param {?} groupName
     * @param {?} siteurl
     * @return {?}
     */
    removeUserCollectionFromGroup(users, groupName, siteurl) {
        let /** @type {?} */ requestBody = this.xmlPayloadWrapperStart + this.removeUserCollectionFromGroupPayload + this.xmlPayloadWrapperEnd;
        requestBody = requestBody.replace("groupNamePayload", groupName);
        let /** @type {?} */ internalpayload = "";
        for (let /** @type {?} */ x = 0; x < users.length; x++) {
            internalpayload += "<User LoginName=\"" + users[x].login + "\"/>";
        }
        requestBody = requestBody.replace("usersPayload", internalpayload);
        return this.http.post(siteurl + this.serviceUrl, requestBody, { headers: this.headers, responseType: 'text' })
            .toPromise()
            .then(function (res) {
            return 0;
        })
            .catch(this.handleError);
    }
    /**
     * @param {?} groupName
     * @param {?} siteUrl
     * @return {?}
     */
    getUserCollectionFromGroup(groupName, siteUrl) {
        let /** @type {?} */ requestBody = this.xmlPayloadWrapperStart + this.getUserCollectionFromGroupPayload + this.xmlPayloadWrapperEnd;
        requestBody = requestBody.replace("groupNamePayload", groupName);
        return this.http.post(siteUrl + this.serviceUrl, requestBody, { headers: this.headers, responseType: 'text' })
            .toPromise()
            .then(function (res) {
            let /** @type {?} */ result = [];
            $(res).find("User").each(function (index) {
                result.push({ id: $(this).attr('ID'), displayName: $(this).attr('Name'), login: $(this).attr('LoginName'), email: $(this).attr('Email') });
            });
            return result;
        })
            .catch(this.handleError);
    }
    /**
     * @param {?} error
     * @return {?}
     */
    handleError(error) {
        console.error('An error occurred', error); // for demo purposes only
        return Promise.reject(error.message || error);
    }
}
SharepointUserGroupWebService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
SharepointUserGroupWebService.ctorParameters = () => [
    { type: HttpClient, },
];

class NgTaxServices {
    /**
     * @param {?} parentModule
     */
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('NgTaxServices / NgTaxSharePointWebServicesModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: NgTaxServices,
            providers: [SharepointListsWebService, UrlService, SharePointUserProfileWebService, SharepointUserGroupWebService]
        };
    }
}
NgTaxServices.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [],
                exports: []
            },] },
];
/**
 * @nocollapse
 */
NgTaxServices.ctorParameters = () => [
    { type: NgTaxServices, decorators: [{ type: Optional }, { type: SkipSelf },] },
];

/**
 * @abstract
 */
class SharepointListItem {
    /**
     * @param {?=} rawResponse
     */
    constructor(rawResponse) {
        if (rawResponse) {
            this.ID = +this.findString('ows_id', rawResponse);
            for (let x = 0; x < this.getItemProperties().length; x++) {
                this[this.getItemProperties()[x]] = this.findString('ows_' + this.getItemProperties()[x].toLowerCase(), rawResponse);
            }
        }
    }
    /**
     * @param {?} searchTerm
     * @param {?} myArray
     * @return {?}
     */
    findString(searchTerm, myArray) {
        for (let /** @type {?} */ x = 0; x < myArray.length; x++) {
            if (myArray[x].name == searchTerm) {
                return myArray[x].value;
            }
        }
        return '';
    }
    /**
     * @abstract
     * @return {?}
     */
    getSiteUrl() { }
    /**
     * @abstract
     * @return {?}
     */
    getListName() { }
    /**
     * @abstract
     * @return {?}
     */
    getFieldToUpdate() { }
    /**
     * @return {?}
     */
    getItemProperties() {
        return [];
    }
    /**
     * @param {?} aString
     * @return {?}
     */
    toBoolean(aString) {
        if (this[aString]) {
            this[aString] = this[aString] && this[aString] == "true";
        }
    }
    /**
     * @param {?} aString
     * @return {?}
     */
    toInteger(aString) {
        if (this[aString] && this[aString].includes(".")) {
            this[aString] = this[aString].split(".")[0];
        }
    }
    /**
     * @param {?} id
     * @param {?} keyValuePairs
     * @return {?}
     */
    static buildRawResponseArray(id, keyValuePairs) {
        let /** @type {?} */ response = [];
        response.push({ name: "ows_id", value: id });
        for (let /** @type {?} */ keyValuePair of keyValuePairs) {
            response.push({ name: "ows_" + keyValuePair[0].toLowerCase(), value: keyValuePair[1] });
        }
        return response;
    }
}

class UserInfoListEntry extends SharepointListItem {
    /**
     * @param {?=} rawResponse
     */
    constructor(rawResponse) {
        super(rawResponse);
        
    }
    /**
     * @return {?}
     */
    getItemProperties() {
        return ["title", "jobTitle", "name", "email"];
    }
    /**
     * @return {?}
     */
    getSiteUrl() {
        return '/';
    }
    /**
     * @return {?}
     */
    getListName() {
        return 'UserInfo';
    }
    /**
     * @return {?}
     */
    getFieldToUpdate() {
        return 'Not implemented';
    }
}

class TaxSpUser {
}

/**
 * Generated bundle index. Do not edit.
 */

export { NgTaxServices, SharepointListsWebService, UrlService, SharePointUserProfileWebService, SharepointUserGroupWebService, SharepointListItem, SharePointUserProfile, UserInfoListEntry, TaxSpUser, XmlUtilities };
//# sourceMappingURL=ng-tax-share-point-web-services-module.js.map
